// RenderEngine class implementation
#include "pch.h"

#include "RenderEngine.h"
#include "util.h"

namespace nf::cli::render {
    RenderEngine::RenderEngine()
        : m_instance()
    {
        NFLog("Initializing render engine");
        createInstance();
    }

    void RenderEngine::createInstance() {
        VkApplicationInfo appInfo = { VK_STRUCTURE_TYPE_APPLICATION_INFO };
        appInfo.apiVersion = VK_API_VERSION_1_0;

        VkInstanceCreateInfo instanceCI = { VK_STRUCTURE_TYPE_INSTANCE_CREATE_INFO };
        instanceCI.pApplicationInfo = &appInfo;
#ifdef _DEBUG
        const char* validationLayerName = "VK_LAYER_KHRONOS_validation";
        instanceCI.ppEnabledLayerNames = &validationLayerName;
        instanceCI.enabledLayerCount = 1;
#endif
        std::vector<const char*> instanceExtNames = { VK_KHR_SURFACE_EXTENSION_NAME, VK_KHR_WIN32_SURFACE_EXTENSION_NAME };
        instanceCI.ppEnabledExtensionNames = instanceExtNames.data();
        instanceCI.enabledExtensionCount = instanceExtNames.size();
        if (vkCreateInstance(&instanceCI, nullptr, &m_instance) != VK_SUCCESS)
            NFError("Could not create Vulkan instance.");
    }

    RenderEngine::~RenderEngine() {
        vkDestroyInstance(m_instance, nullptr);
    }
}
